2024-12-09 Version: 4.3.0
- Support API CancelActiveOperationTasks.
- Support API CheckServiceLinkedRole.
- Support API CreateServiceLinkedRole.
- Support API DescribeActiveOperationMaintainConf.
- Support API DescribeActiveOperationTasks.
- Support API DescribeHistoryEventsStat.
- Support API DescribeKmsKeys.
- Support API DescribeLoghubDetail.
- Support API DescribeRegionsMixed.
- Support API DescribeSyncAvailableDBClusterList.
- Support API DescribeSyncJobList.
- Support API DescribeVSwitchs.
- Support API DescribeVpcs.
- Support API ModifyActiveOperationMaintainConf.
- Support API ModifyActiveOperationTasks.
- Support API ModifyDBClusterVip.
- Support API ModifyLogHubStatus.
- Support API ModifySyncJob.
- Support API OperateLogHub.
- Update API AttachUserENI: add param AccessKeyId-copy.
- Update API AttachUserENI: update param AccessKeyId.
- Update API DescribeDiagnosisTasks: update response param.
- Update API UpgradeKernelVersion: update param DBVersion.
- Update API UpgradeKernelVersion: update param SwitchMode.


2024-11-08 Version: 4.2.1
- Update API DescribeDBClusterPerformance: update response param.
- Update API DescribeDBClusterShardNumber: update response param.


2024-10-31 Version: 4.2.0
- Support API DeleteBackups.


2024-10-28 Version: 4.1.1
- Update API DescribeDBClusterSSL: add param RegionId.


2024-10-25 Version: 4.1.0
- Support API DescribeDBClusterShardNumber.
- Update API DescribeInclinedTables: update param PageSize.


2024-10-23 Version: 4.0.0
- Support API DescribeDBClusterSSL.
- Support API DescribeDBClusterSpaceSummary.
- Support API DescribeExcessivePrimaryKeys.
- Support API DescribeKernelVersion.
- Support API ModifyDBClusterSSL.
- Support API UpgradeKernelVersion.
- Delete API DescribeSlowLogTrend.
- Update API BatchApplyAdviceByIdList: update response param.
- Update API CreateDBCluster: add param EnableSSL.
- Update API CreateDBCluster: update param DiskEncryption.
- Update API CreateElasticPlan: add param ElasticPlanWeeklyRepeat.
- Update API CreateElasticPlan: add param ElasticPlanMonthlyRepeat.
- Update API CreateElasticPlan: update param ElasticPlanWeeklyRepeat.
- Update API CreateElasticPlan: update param ResourcePoolName.
- Update API DescribeAllAccounts: update response param.
- Update API DescribeAppliedAdvices: add param AdviceType.
- Update API DescribeAppliedAdvices: add param Keyword.
- Update API DescribeAppliedAdvices: add param Order.
- Update API DescribeAppliedAdvices: add param SchemaTableName.
- Update API DescribeAppliedAdvices: update response param.
- Update API DescribeAuditLogConfig: update response param.
- Update API DescribeAuditLogRecords: update param EndTime.
- Update API DescribeAuditLogRecords: update param StartTime.
- Update API DescribeAuditLogRecords: update response param.
- Update API DescribeAvailableAdvices: add param AdviceType.
- Update API DescribeAvailableAdvices: add param Keyword.
- Update API DescribeAvailableAdvices: add param Order.
- Update API DescribeAvailableAdvices: add param SchemaTableName.
- Update API DescribeAvailableAdvices: update response param.
- Update API DescribeBackups: add param CrossRole.
- Update API DescribeBackups: add param CrossUid.
- Update API DescribeBackups: add param RegionId.
- Update API DescribeBackups: update param EndTime.
- Update API DescribeBackups: update param StartTime.
- Update API DescribeBackups: update response param.
- Update API DescribeDBClusterAccessWhiteList: add param RegionId.
- Update API DescribeDBClusterAttribute: add param RegionId.
- Update API DescribeDBClusterAttribute: update response param.
- Update API DescribeDBClusterNetInfo: add param RegionId.
- Update API DescribeDBClusterNetInfo: update response param.
- Update API DescribeDBClusters: update response param.
- Update API DescribeDBResourceGroup: update response param.
- Update API DescribeDiagnosisDimensions: update response param.
- Update API DescribeDiagnosisMonitorPerformance: update response param.
- Update API DescribeDiagnosisRecords: update response param.
- Update API DescribeEIURange: add param StorageSize.
- Update API DescribeEIURange: add param SubOperation.
- Update API DescribeEIURange: update param ComputeResource.
- Update API DescribeEIURange: update param Operation.
- Update API DescribeEIURange: update response param.
- Update API DescribeElasticPlan: update response param.
- Update API DescribeInclinedTables: add param Lang.
- Update API DescribeInclinedTables: add param RegionId.
- Update API DescribeInclinedTables: update param DBClusterId.
- Update API DescribeInclinedTables: update response param.
- Update API DescribePatternPerformance: update response param.
- Update API DescribeRegions: add param RegionId.
- Update API DescribeSQLPatterns: update response param.
- Update API DescribeTableDetail: add param RegionId.
- Update API DescribeTableDetail: update param DBClusterId.
- Update API DescribeTableDetail: update response param.
- Update API DescribeTablePartitionDiagnose: add param Lang.
- Update API DescribeTablePartitionDiagnose: add param Order.
- Update API DescribeTablePartitionDiagnose: delete param Action.
- Update API DescribeTablePartitionDiagnose: update param AccessKeyId.
- Update API DescribeTablePartitionDiagnose: update param DBClusterId.
- Update API DescribeTablePartitionDiagnose: update param OwnerAccount.
- Update API DescribeTablePartitionDiagnose: update param OwnerId.
- Update API DescribeTablePartitionDiagnose: update param ResourceOwnerAccount.
- Update API DescribeTablePartitionDiagnose: update param ResourceOwnerId.
- Update API DescribeTablePartitionDiagnose: update response param.
- Update API DescribeTableStatistics: add param Keyword.
- Update API DescribeTableStatistics: update param RegionId.
- Update API DescribeTableStatistics: update response param.
- Update API MigrateDBCluster: add param ComputeResource.
- Update API MigrateDBCluster: add param ShardNumber.
- Update API MigrateDBCluster: add param StorageResource.
- Update API MigrateDBCluster: add param StorageResourceSize.
- Update API ModifyBackupPolicy: update param PreferredBackupPeriod.
- Update API ModifyDBClusterPayType: add param RegionId.
- Update API ModifyDBResourceGroup: add param PoolUserList.
- Update API ModifyElasticPlan: add param ElasticPlanMonthlyRepeat.
- Update API ModifyElasticPlan: update param ResourcePoolName.


2024-02-20 Version: 3.1.2
- Update API CreateElasticPlan: add param ElasticPlanWeeklyRepeat.
- Update API CreateElasticPlan: add param ElasticPlanMonthlyRepeat.
- Update API CreateElasticPlan: update param ElasticPlanWeeklyRepeat.
- Update API CreateElasticPlan: update param ResourcePoolName.
- Update API DescribeAuditLogRecords: update param EndTime.
- Update API DescribeAuditLogRecords: update param StartTime.
- Update API DescribeAuditLogRecords: update response param.
- Update API DescribeDiagnosisRecords: update response param.
- Update API DescribeElasticPlan: update response param.
- Update API DescribeTableStatistics: add param Keyword.
- Update API DescribeTableStatistics: update response param.
- Update API ModifyElasticPlan: add param ElasticPlanMonthlyRepeat.
- Update API ModifyElasticPlan: update param ResourcePoolName.


2024-02-06 Version: 3.1.1
- Generated python 2019-03-15 for adb.

2023-12-11 Version: 3.1.0
- Generated python 2019-03-15 for adb.

2023-10-23 Version: 3.0.0
- Generated python 2019-03-15 for adb.

2023-09-19 Version: 2.0.0
- Generated python 2019-03-15 for adb.

2023-08-31 Version: 1.1.2
- Generated python 2019-03-15 for adb.

2023-08-22 Version: 1.1.1
- Generated python 2019-03-15 for adb.

2023-08-17 Version: 1.1.0
- Generated python 2019-03-15 for adb.

2022-05-26 Version: 1.0.11
- Support ModifyDBClusterPayType.

2022-01-05 Version: 1.0.10
- Move to perth for DescribeAuditLogRecords.
- Move to perth for DescribeAuditLogConfig.

2021-10-25 Version: 1.0.9
- CreateDBCluster Support ElasticResourceIO.

2021-05-14 Version: 1.0.8
- Update CreateDBCluster.
- Update ModifyDBCluster.

2021-03-31 Version: 1.0.7
- Generated python 2019-03-15 for adb.

2021-03-12 Version: 1.0.6
- Supportd DescribeTableStatisticsRequest.

